%
% Simple matlab script to generate slice plots of the CMOD5 V-polarization
% polarization model function for various azimuth and incidence angles,
% wind speeds and directions, and antenna azimuth angles.  Uses the
% CMOD5.m script
%
% Written by D.G. Long at BYU Jan 2012
%

clear
figure(1);clf

% first generate sigma^0 versus wind speed at several incidence angles
subplot(2,1,1)
spds=2:30;
z=spds*0;
incs=20:10:60;

for i=incs
  sig=CMOD5([spds' z' z' i+z']);
  semilogx(spds,10*log10(sig));
  hold on;
end
hold off;
title('C-band CMOD5');
xlabel('Wind speed U (m/s)');
ylabel('Backscattering (dB)');
legend('20 deg','30 deg','40 deg','50 deg','60 deg')

% generate sigma^0 versus wind direction at several speeds
subplot(2,1,2)
az=0:360;
spds=[5,10,15,20,30];

for i=spds
  sig=CMOD5([i+0*az' az' 0*az' 45+0*az']);
  plot(az,10*log10(sig));
  hold on;
end
hold off;
title('C-band CMOD5');
xlabel('Relative wind direction (deg)');
ylabel('Backscattering (dB)');
legend('5 m/s','20 m/s','15 m/s','20 m/s','30 m/s')

% save graphic
print -dpng CMOD5.png
