function bestspd=ravine_CMOD5(dir,arg)
% 
% bestspd=ravine_CMOD5(dir,arg)
%
% Use least-squares estimation to estimate the best speed at
% a given direction dir, given measurements and their corresponding
% geometry where the i-th row of arg is given by arg(i,:)=[sigma-0 A,T]
% with 
%   sigma-0 is the sigma-0 measurement (normal space)
%   A is the antenna azimuth angle relative to north in deg
%   T is the incidence angle in deg (26-66)
%
% returned speed is in m/s
%
% written by D.G. Long at BYU Dec 2011
%

% extract columns of input rows
sig=arg(:,1)';  % sigma-0
A=inarg(:,2)';  % radar azimuth angle
T=inarg(:,3)';  % incidence angle

% search algorithm is a simple binary search in speed that assumes
% that sigma-0 versus wind speed at particular direction and geometry
% is monotonic

niter=1;
Maxiter=5;
low=1;
high=50;

zcol=zeros(size(sig'));

arglow=[low+zcol, dir+zcol,A,T];
siglow=CMOD5(arglow);
arghigh=[high+zcol, dir+zcol,A,T];
sighigh=CMOD5(arghigh);
half=(low+half)*0.5;
arghalf=[half+zcol,dir+zcol,A,T];
sighalf=CMOD5(arghalf);

LSlow=(sig-siglow).^2;
LShigh=(sig-sighigh).^2;
LShalf=(sig-sighalf).^2;

while iter<Maxiter,
  if LShalf<LSlow & LShalf<LShigh
    low1=low+(half-low)/2;
    high1=high-(high-half)/2;    
    arglow1=[low+zcol, dir+zcol,A,T];
    siglow1=CMOD5(arglow1);
    arghigh1=[high+zcol, dir+zcol,A,T];
    sighigh1=CMOD5(arghigh1);
    LSlow1=(sig-siglow1).^2;
    LShigh1=(sig-sighigh1).^2;
    if LShalf<LSlow1 & LShalf<LShigh1
    else if LSlow1<LShalf
      
    else if LShigh1<Lshalf
    end
      
  else if LSlow<LShalf
  else if LShigh<LShalf
  else if LShalf>LSlow & LShalf>LShigh % local peak
  
  end
  iter=iter+1;
  iter=iter+1;
end